==> ukelli-ui-3.0.0.tgz: package/core/icon/icon.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import React from 'react';
import { getIcon } from '../config';
var Icon = function (props) {
    var n = props.n, s = props.s, useIconConfig = props.useIconConfig, type = props.type, _a = props.classNames, classNames = _a === void 0 ? [] : _a, className = props.className, other = __rest(props, ["n", "s", "useIconConfig", "type", "classNames", "className"]);
    var iconClassName = getIcon((n || type), s, ['icon', (className || '')].concat(classNames), useIconConfig);
    return (React.createElement("i", __assign({}, other, { className: iconClassName })));
};
Icon.defaultProps = {
    n: 'none',
    s: 's',
    useIconConfig: true,
    classNames: [],
};
var PureIcon = function (props) { return (React.createElement(Icon, __assign({}, props, { useIconConfig: false }))); };
export { PureIcon };
export default Icon;

==> ukelli-ui-3.3.1.tgz: package/core/icon/icon.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import React from 'react';
import { getIcon } from '../config';
var Icon = function (props) {
    var n = props.n, s = props.s, useIconConfig = props.useIconConfig, type = props.type, _a = props.classNames, classNames = _a === void 0 ? [] : _a, className = props.className, other = __rest(props, ["n", "s", "useIconConfig", "type", "classNames", "className"]);
    var iconClassName = getIcon((n || type), s, __spreadArrays(['icon', (className || '')], classNames), useIconConfig);
    return (React.createElement("i", __assign({}, other, { className: iconClassName })));
};
Icon.defaultProps = {
    n: 'none',
    s: 's',
    useIconConfig: true,
    classNames: [],
};
var PureIcon = function (props) { return (React.createElement(Icon, __assign({}, props, { useIconConfig: false }))); };
export { PureIcon };
export default Icon;
